##  1. Purpose and scope
The purpose of this Data Privacy Statement (“Statement“) is to provide information to the Users of the SAP LeanIX workspaces as to the type of information the SAP LeanIX software may process on behalf of the controller (i.e. the customer), as well as how such information may be used and the relevant data subject rights.
This Statement explains the following:
  * Who is Data Controller?
  * What is the scope of processing?
  * What are the rights of a User?
